% Runs multiple instances of disorder, this time directly checking
% optomechanical coupling value to ensure we do indeed have a good result

%% Define input parameters
P.lambda = 1567e-9;                 % center wavelength
P.freq = 11.11e+9;                   % mechanical frequency center frequency
P.neigs = 20;                       % number of eigenvalues to find
P.type = 'NanobeamHalfCross';       % type of crystal
P.a = 3.00e-7;                      % nominal nanobeam lattice constant
% Jasper's numbers
P.hh = 0.9e-7*0.95;
P.hw = 2.00e-7*0.99;
P.w = 5.5e-7;
P.mDef = 0.25;
P.oblong = 1.6508;
 
crossScaleup =1;
P.aC = 240e-9*crossScaleup;  
P.hC = 220e-9*crossScaleup;
P.wC = 85e-9*crossScaleup;
P.fillet= 32e-9;%54.1e-9;

P.xC = 0;
P.yC = 0;
% Jasper's numbers ended
P.nC = 4;                           % number of cross periods
P.nNom = 11;                        % number of mirror periods in 1/2 nanobeam
P.nDef = 6.5;                       % number of cells in 1/2 defect
stdDev = 0;
P.stdDev = [stdDev/100*P.hh/2 stdDev/100*P.hw/2 stdDev/100*P.hC stdDev/100*P.wC];%[0.02*P.hh/2 0.02*P.hw/2 0.02*P.hC 0.02*P.wC];  %[0 0 0 0];%[0.05*P.hh/2 0.05*P.hw/2 0.05*P.hC 0.05*P.wC];               % randomness in hh/2, hw/2, hC, wC
P.stdDevPos = stdDev*1e-9;                    % randomness in hole positions
P.wS = 6e-6;                     % should probably measure this manually each time
P.mechPML = 1;                      % whether to use PML
P.mechPMLStr = 0.05;                % mechanical PML strength
P.maxDoF = 0.5e6;                     % maximum number of degrees of freedom
P.PMLLen = 4e-6;                    % length of PML
P.PMLStart = 1e-6;                  % starting distance of PML
P.E = 170e9;                        % Young's modulus (Pa)
P.rho = 2329;                       % density (kg/m^3)
P.nu = 0.28;                        % Poisson's ratio
P.D = 1e9*[166,64,64,0,0,0, ...     % Anisotropic elsaticity tensor
          166,64,0,0,0, ...
          166,0,0,0, ...
          80,0,0, ...
          80,0, ...
          80]; 
% P.D = 1e9*[166,64,64,0,0,0, ...     % Anisotropic elsaticity tensor 011 direction
%               195,35,0,0,0, ...
%                  195,0,0,0, ...
%                     51,0,0, ...
%                       80,0, ...
%                         80]; 
P.useSym = [0 0 1];                 % whether to use symmetry in x,y,z direction, 1 is use
P.sym = [1 1 1];                    % 1 is symmetric, 0 is antisymmetric
P.thi = 2.2e-7;                     % thickness of slab
P.rFillet = 0;                      % fillet radius of holes
P.kPts = 20;                        % number of k points to scan over
P.n = 3.48;                         % index of refraction in material
P.air = 2e-6;                       % thickness of surounding air box

% Define filename
fnpref = 'PhGregScale';    % filename prefix
% Define simulation parameters
R.ms = 1;                           % 1 = sweptmesh, 0 = traditional mesh
R.mq = 0.7;                           % mesh quality
R.ld = 40;                          % lambdaDiv factor
R.sl = 1;                           % number of swept layers
R.PMLms = 1;                        % similar parameters for the mechanical PML
R.PMLmq = 5;
R.PMLld = 10;
R.PMLsl = 1;

npoints = 10;
disorder1 = stdDev;
disorder2 = stdDev;
res = [];
resall = [];

[slabInfo,holeInfo,fixedBounds,startPML] = generateSlabHoleNanobeamHalfCrossSubdom(P);
P.pG.slabInfo = slabInfo;
P.pG.holeInfo = holeInfo;
P.pG.fixedBounds = fixedBounds;
P.pG.startPML = startPML;

Pc = rmfield(P,'pG');
Pc.type = 'Cross';
Pc.freq = 0;
Pc.kPts = 20;
Pc.neigs = 20;
Pc.a = P.aC;
Pc.h = P.hC;
Pc.w = P.wC;
Pc.useSym = [0 0 0];
tic
dsc = runMechBands(Pc);
toc
fc = dsc.F;
save(['fc_' num2str(P.aC*1e9) '_' num2str(P.hC*1e9) '_' num2str(P.wC*1e9) '_' num2str(P.fillet*1e9) '.mat'],'fc');


