% Runs multiple instances of disorder, this time directly checking
% optomechanical coupling value to ensure we do indeed have a good result
global femtest;
global a;
global b;
nanobeamScale = 1.03;  %scale nanobeams only
%% Define input parameters
P.lambda = 1567e-9;                 % center wavelength
P.freq = 5.2e+9/nanobeamScale;                   % mechanical frequency center frequency
P.neigs = 30;                       % number of eigenvalues to find
P.type = 'NanobeamHalfCross';       % type of crystal
P.aC = 5.34e-7;                     % nominal cross lattice constant
P.a = 4.36e-7*nanobeamScale;                      % nominal nanobeam lattice constant
% Jasper's numbers
P.hh = 1.65e-7*nanobeamScale;
P.hw = 3.66e-7*nanobeamScale;

fittedCavityhh = [0.8400
    0.6700
    0.5680
    0.4900
    0.4250
    0.4060
    0.3920
    0.4040
    0.4390
    0.4850
    0.5700
    0.6640
    0.8400];


fittedCavityhw = 0.9856 * [0.3780
    0.3980
    0.4140
    0.4360
    0.4550
    0.4640
    0.4690
    0.4650
    0.4470
    0.4320
    0.4140
    0.3950
    0.3780];

P.fittedCavityhw=fittedCavityhw*P.a;
P.fittedCavityhh=fittedCavityhh*P.a;

P.hh = (fittedCavityhh(1)/2+fittedCavityhh(end)/2)*P.a;
P.hw = (fittedCavityhw(1)/2+fittedCavityhw(end)/2)*P.a;

P.fittedindices = [11:23]; %cavity holes, including 2 mirrors
P.useFittedCavity = 1; %if we use real fitted data instead of nominal

P.w = 5.34e-7*nanobeamScale;
P.mDef = 0.25;
P.oblong = 1.6508;
P.hC = 4.74e-7;
P.wC = 1.64e-7;
P.xC = 0;
P.yC = 0;
% Jasper's numbers ended
P.nC = 4;                           % number of cross periods
P.nNom = 11;                        % number of mirror periods in 1/2 nanobeam
P.nDef = 6.5;                       % number of cells in 1/2 defect

P.tiltWall = 0e-9;                	% P.wTop-P.wbtm
P.scaleTopY = 1;                    % P.wTop/P.wbtm

P.roughBeamSections = 0*2;           % How many section we break the beam into, for beam roughness, 
                                    %if roughBeamSections==0, use old rect instead of ploygon

P.crossfillet = 40e-9;              % fillet for cross shields

stdDev = 0;
stdDevPos = 0;
stdDevRoughBeam = 0;
P.stdDev = [stdDev/100*P.hh/2 stdDev/100*P.hw/2 stdDev/100*P.hC stdDev/100*P.wC];%[0.02*P.hh/2 0.02*P.hw/2 0.02*P.hC 0.02*P.wC];  %[0 0 0 0];%[0.05*P.hh/2 0.05*P.hw/2 0.05*P.hC 0.05*P.wC];               % randomness in hh/2, hw/2, hC, wC
P.stdDevPos = stdDevPos*1e-9;                    % randomness in hole positions (nm)
P.stdDevTiltWal = 0e-9;                    % randomness in tiltWal positions (nm)
P.stdDevRoughBeam = stdDevRoughBeam*1e-9;  % randomness in beam roughness positions (nm) for each break points along the beam

P.wS = 6e-6;                        % should probably measure this manually each time
P.mechPML = 1;                      % whether to use PML
P.mechPMLStr = 0.05;                % mechanical PML strength
P.maxDoF = 8e6;                     % maximum number of degrees of freedom
P.PMLLen = 4e-6;                    % length of PML
P.PMLStart = 1e-6;                  % starting distance of PML
P.E = 170e9;                        % Young's modulus (Pa)
P.rho = 2329;                       % density (kg/m^3)
P.nu = 0.28;                        % Poisson's ratio
P.D = 1e9*[166,64,64,0,0,0, ...     % Anisotropic elsaticity tensor
    166,64,0,0,0, ...
    166,0,0,0, ...
    80,0,0, ...
    80,0, ...
    80];
P.useSym = [0 0 1];                 % whether to use symmetry in x,y,z direction, 1 is use
P.sym = [1 1 1];                    % 1 is symmetric, 0 is antisymmetric
P.thi = 2.2e-7;                     % thickness of slab
P.rFillet = 0;                      % fillet radius of holes
P.kPts = 20;                        % number of k points to scan over
P.n = 3.48;                         % index of refraction in material
P.air = 2e-6;                       % thickness of surounding air box

% Define filename
fnpref = 'PhGregScale';    % filename prefix
% Define simulation parameters
R.ms = 1;                           % 1 = sweptmesh, 0 = traditional mesh
%R.mq = 0.7;                           % mesh quality
R.mq = 1;                           % mesh quality
R.ld = 55;                          % lambdaDiv factor
R.sl = 1;                           % number of swept layers
R.PMLms = 1;                        % similar parameters for the mechanical PML
R.PMLmq = 5;
R.PMLld = 10;
R.PMLsl = 1;

npoints = 1;

stdDevArray = [0];
stdDevPosArray = [0];
tiltWallArray = [0];
stdDevRoughBeamArray = [0];

for aa = 1:length(stdDevArray)
    for bb = 1:length(stdDevPosArray)
        for cc = 1:length(tiltWallArray)
            for dd = 1:length(stdDevRoughBeamArray)
                
                stdDev = stdDevArray(aa);
                stdDevPos = stdDevPosArray(bb);
                stdDevRoughBeam = stdDevRoughBeamArray(dd);
                P.stdDev = [stdDev/100*P.hh/2 stdDev/100*P.hw/2 stdDev/100*P.hC stdDev/100*P.wC];%[0.02*P.hh/2 0.02*P.hw/2 0.02*P.hC 0.02*P.wC];  %[0 0 0 0];%[0.05*P.hh/2 0.05*P.hw/2 0.05*P.hC 0.05*P.wC];               % randomness in hh/2, hw/2, hC, wC
                P.stdDevPos = stdDevPos*1e-9;
                P.stdDevRoughBeam = stdDevRoughBeam*1e-9;
                
                P.tiltWall = tiltWallArray(cc)*1e-9;
                
                
                disorder1 = stdDev;
                disorder2 = stdDevPos;
                res = [];
                resall = [];
                
                dirname = ['hh',num2str(P.hh*1e7),'_hw',num2str(P.hw*1e7),'_w',num2str(P.w*1e7), ...
                    '_hC',num2str(P.hC*1e7),'_wC',num2str(P.wC*1e7),...
                    '_SIZE',num2str(disorder1),'%_POS',num2str(disorder2),'nm_tiltWall',num2str(P.tiltWall*1e9),'nm', ...
                    '_roughBeam',num2str(P.stdDevRoughBeam*1e9),'nm_ms',num2str(R.ms),'_ld',num2str(R.ld),'/'];
                unix(['mkdir ' dirname]);
                
                
                for k = [0]
                    P.nC = k;
                    dirname1=[dirname 'nC_' num2str(P.nC) '/'];
                    unix(['mkdir ' dirname1]);
                    for i = 1:npoints
                        tic
                        error = 1;
                        disp(['--------- Started running stdDev = ' num2str(stdDev) ' stdDevPos = ' num2str(stdDevPos) ' nC = ' num2str(P.nC) ' itr = ' num2str(i) ' ---------'])
                        while error == 1
                            try
                                
                                
                                P.tiltWall = randomize(P.tiltWall,P.stdDevTiltWal);
                                P.scaleTopY = (P.w+P.tiltWall/2)/(P.w-P.tiltWall/2);  %calculate Scaling factor for scaled extrude
                                
                                if P.useSym(3) == 0 % if not using sym on z, need to update P.w in order for middle of beam to be real P.w
                                    P.wtemp=P.w;
                                    P.w=P.w/(((P.scaleTopY-1)/2)+1);
                                end
                                
                                [slabInfo,holeInfo,fixedBounds,startPML] = generateSlabHoleNanobeamHalfCrossSubdom_roughBeam(P);
                                P.pG.slabInfo = slabInfo;
                                P.pG.holeInfo = holeInfo;
                                P.pG.fixedBounds = fixedBounds;
                                P.pG.startPML = startPML;
                                
                                if P.useSym(3) == 0 % if not using sym on z, change P.w back for the next simulation
                                    P.w=P.wtemp;
                                end
                                %}
                                
                                dsm = runMechSubdom(P,'Q',R);
                                
                                % find 5/10 highest Q mechanical modes
                                Qmvals = dsm.freqs./dsm.decay;
                                dsm.Qmvals = Qmvals;
                                [~,sortInd] = sort(Qmvals(:),'descend');
                                mModes = sortInd(1:10);
                                
                                
                                
                                error = 0;
                            catch
                                disp(lasterror);
                                a  = lasterror;
                                error =1;
                            end
                            
                        end
                        toc
                        for m=1:length(mModes)
                            
                            figure;
                            modeplot_Ey(dsm.fem,mModes(m),180);
                            title(['Frequency =', num2str(dsm.fem.sol.lambda(mModes(m))*1i/2/pi,'%3.3e') ,'    Q(log) = ', num2str(log10(dsm.Qmvals(mModes(m))),'%3.3f')]);
                            view(0,90);
                            xlim([-5e-6 5e-6]);
                            ylim([-1e-6 1e-6]);
                            fname = ['itr_' num2str(i) '_Mode_' num2str(m) '.png'];
                            fnamefig = ['itr_' num2str(i) '_Mode_' num2str(m) '.fig'];
                            saveas(gcf,[dirname1,fname],'png')
                            saveas(gcf,[dirname1,fnamefig])
                            close all;
                        end
                        
                    end
                    %save([dirname,fn,'allPoints'],'P','R','res')
                    %resall=[resall;res];
                    %clear res;
                    %res = [];
                    %close all
                end
            end
        end
    end
end
%save([dirname,fn,'all_nC_allPoints'],'P','R','resall')