function [bnd] = bndindex(g,p0,varargin)
% Returns the indices of the faces that are coplanar with the specified plane.
% p0 is a point in the plane. The first element of varargin is the normal
% vector to the plane. The second element of varargin, if there is one, is
% a double which specifies the maximum distance allowed from p0 for a point
% to be considered "inplane". This is to allow us to find indices of
% certain boundaries if they happen to be coplanar with boundaries that we
% do not want to select. If no distance parameter is entered, it is set to
% infinity. To maintain compatibility with Thiago's older version of
% bndindex, the second element of varargin can be a vector, in which case
% the normal is set to the cross product of varargin{1}-p0 and
% varargin{2}-p0
n = varargin{1};
dist = Inf;
tol = 1e-10;
if length(varargin) > 1 
    if length(varargin{2}) == 1
        dist = varargin{2};
    else
        n = cross(varargin{1}-p0,varargin{2}-p0);
    end
end
if(dot(n,n)==0) 
	error('Normal not specified correctly.');
end
p = cell2mat(geominfo(g,'out','xx','par',num2cell(num2cell([1:geominfo(g,'out','no','Od',0)]))));   % finds all vertices
vx = p(:,:,1)-p0(1);
vy = p(:,:,2)-p0(2);
vz = p(:,:,3)-p0(3);
inplane = (abs(vx*n(1)+vy*n(2)+vz*n(3))<max(abs(vx*n(1)+vy*n(2)+vz*n(3)))*tol) ...  % check's whether point is in plane
         &(sqrt(vx.^2+vy.^2+vz.^2) < dist); % check whether point is within a certain distance
adj = geominfo(g,'out','adj','Odp',[2;0]);  % adjacency matrix between points and planes, adj{1}(i,j) is object i of dim 2
% and object j of dim 0 are adjacent
bnd = find(sum(adj{1}(:,inplane),2)==sum(adj{1},2));    % find planes which have all their vertices in "inplane"