% Generates slab and hole information for a single nanobeam unit cell.
% The input structure P is expected to have the following fields:
%
% P.a = lattice spacing; P.hh/hw = hole height/width; P.w = beam width; 
% P.useSym = 3 element vector detailing whether or not to use symmetry;
%
% Sean Meenehan, 9/12/13

function [slabs,holes,latticeVecs,fixedBounds] = generateUnitCellNanobeam(P)

a = P.a;
hh = P.hh;
hw = P.hw;
w = P.w;
useSym = P.useSym;

% Create the beam slab
slab.type = 'Rectangle';
slab.wx = a;
slab.x = P.a/2;
if useSym(2)
    slab.wy = w/2;
    slab.y = w/4;
else
    slab.wy = w;
    slab.y = 0;
end
slabs = {slab};

slab.type = 'Air';
if useSym(2)
    slab.wy = w/2+2e-6;
    slab.y = w/4+1e-6;
else
    slab.wy = w+4e-6;
    slab.y = 0;
end
slabs{end+1} = slab;

holes = {};
hole.type = 'Ellipse';
hole.x = 0;
hole.y = 0;
hole.rx = hh/2;
hole.ry = hw/2;
holes{end+1} = hole;
hole.x = a;
holes{end+1} = hole;

latticeVecs = {[a,0,0]};
fixedBounds = {};

