% This script performs a test of the mesh dependence of optomechanical
% coupling and other quantities

%{
%% Define input parameters
P.lambda = 1541e-9;                 % center wavelength
P.freq = 5.1395e+9;                   % mechanical frequency center frequency
P.neigs = 5;                       % number of eigenvalues to find
P.type = 'NanobeamHalfCross';       % type of crystal
P.aC = 5.34e-7;                     % nominal cross lattice constant
P.a = 4.36e-7;                      % nominal nanobeam lattice constant
% Jasper's numbers
P.hh = 1.65e-7;
P.hw = 3.66e-7;
P.w = 5.29e-7;
P.mDef = 0.25;
P.oblong = 1.6508;
P.hC = 4.54e-7;
P.wC = 1.34e-7;
P.xC = 0;
P.yC = 0;
% Jasper's numbers ended
P.nC = 4;                           % number of cross periods
P.nNom = 11;                        % number of mirror periods in 1/2 nanobeam
P.nDef = 6.5;                       % number of cells in 1/2 defect
P.stdDev = [0 0 0 0];               % randomness in hh/2, hw/2, hC, wC
P.stdDevPos = 1e-11;                    % randomness in hole positions
P.wS = 2.79e-6;                     % should probably measure this manually each time
P.mechPML = 1;                      % whether to use PML
P.mechPMLStr = 0.05;                % mechanical PML strength
P.maxDoF = 2e6;                     % maximum number of degrees of freedom
P.PMLLen = 4e-6;                    % length of PML
P.PMLStart = 1e-6;                  % starting distance of PML
P.E = 170e9;                        % Young's modulus (Pa)
P.rho = 2329;                       % density (kg/m^3)
P.nu = 0.28;                        % Poisson's ratio
P.D = 1e9*[166,64,64,0,0,0, ...     % Anisotropic elsaticity tensor
          166,64,0,0,0, ...
          166,0,0,0, ...
          80,0,0, ...
          80,0, ...
          80]; 
P.useSym = [0 0 1];                 % whether to use symmetry in x,y,z direction, 1 is use
P.sym = [1 1 1];                    % 1 is symmetric, 0 is antisymmetric
P.thi = 2.2e-7;                     % thickness of slab
P.rFillet = 0;                      % fillet radius of holes
P.kPts = 20;                        % number of k points to scan over
P.n = 3.48;                         % index of refraction in material
P.air = 2e-6;                       % thickness of surounding air box

% Define filename
fn = 'Phjmesh';    % filename prefix
% Define simulation parameters
R.ms = 1;                           % 1 = sweptmesh, 0 = traditional mesh
R.mq = 0.7;                           % mesh quality
R.ld = 40;                          % lambdaDiv factor
R.sl = 1;                           % number of swept layers
R.PMLms = 1;                        % similar parameters for the mechanical PML
R.PMLmq = 5;
R.PMLld = 10;
R.PMLsl = 1;

dsm = {};
mechmesh = [3,15;3,20;0.7,20;3,40;1,40;0.7,40];
optmesh = [5,3;5,5;5,7;8,5;8,7;3,3;3,5;3,7;2,5];
%
for i = 1:size(mechmesh,1)
    R.mq = mechmesh(i,1);
    R.ld = mechmesh(i,2);
    flag = 0;
    while flag < 10
        try
            dsmtemp = runMechSubdom(P,'Q',R);
            dsm{end+1} = dsmtemp;
            flag = 11;
            save(strcat(fn,'mech',num2str(mechmesh(i,1)),'_',num2str(mechmesh(i,2)),'.mat'),dsmtemp);
        catch
            disp(lasterr);
            flag = flag+1;
        end
    end
end
%
dso = {};
for j = 1:size(optmesh,1)
    P.type = 'Nanobeam';
    flag = 0;
    while flag < 10
        try
            dsotemp = runOptical(P,'meshQuality',optmesh(j,1),'lambdaDiv',optmesh(j,2));
            dso{end+1} = dsotemp;
            flag = 11;
            save(strcat(fn,'opt',num2str(optmesh(j,1)),'_',num2str(optmesh(j,2)),'.mat'),dsotemp);
        catch
            disp(lasterr);
            flag = flag+1;
        end
    end
end
%}
p11 = -0.101;
p12 = 0.0094;
p44 = -0.051;   % temporarily taking numbers from JCB's files
ds2 = {};
for i = 1
    for j = 3:size(optmesh,1)
        try
            ds2temp.mesh = [mechmesh(i,1),mechmesh(i,2),optmesh(j,1),optmesh(j,2)]
            ds2temp.res = calculateGpeCubic(dso{j}.fem,dsm{i}.fem,1:P.neigs,P.useSym,p11,p12,p44);
            ds2{end+1} = ds2temp;
        catch
            disp('error');
        end
    end
end